--[[
    MapZoomEvent

    Multiplayer Sync Event for the RealGPS's Map Zoom change.

	@author: 		BayernGamers
	@date: 			11.03.2025
	@version:		2.0

	History:		v1.0 @15.07.2023 - initial implementation in FS 22
                    ------------------------------------------------------------------------------------------------------
                    v2.0 @11.03.2025 - convert and re-write for FS25
                    ------------------------------------------------------------------------------------------------------
	
	License:        Terms:
                        Usage:
                            Feel free to use this work as-is as long as you adhere to the following terms:
						Attribution:
							You must give appropriate credit to the original author when using this work.
						No Derivatives:
							You may not alter, transform, or build upon this work in any way.
						Usage: 
							The work may be used for personal and commercial purposes, provided it is not modified or adapted.
						Additional Clause:
							This script may not be converted, adapted, or incorporated into any other game versions or platforms except by GIANTS Software.
]]
MapZoomEvent = {}

local MapZoomEvent_mt = Class(MapZoomEvent, Event)

InitEventClass(MapZoomEvent, "MapZoomEvent")

function MapZoomEvent:emptyNew()
    local self = Event.new(MapZoomEvent_mt)
    return self
end

function MapZoomEvent.new(vehicle, zoom)
    local self = MapZoomEvent:emptyNew()
    self.vehicle = vehicle
    self.zoom = zoom

    return self
end

function MapZoomEvent:writeStream(streamId, connection)
    NetworkUtil.writeNodeObject(streamId, self.vehicle)
    streamWriteFloat32(streamId, self.zoom)
end

function MapZoomEvent:readStream(streamId, connection)
    self.vehicle = NetworkUtil.readNodeObject(streamId)
    self.zoom = streamReadFloat32(streamId)
    
    self:run(connection)
end

function MapZoomEvent:run(connection)
    if not connection:getIsServer() then
        g_server:broadcastEvent(self, false, connection, self.vehicle)
    end
    if self.vehicle ~= nil then
        self.vehicle:setMapZoom(self.zoom)
        RealGPS.updateActionEvents(self.vehicle)
    end
end

function MapZoomEvent.sendEvent(vehicle, zoom, noEventSend)
    if noEventSend == nil or noEventSend == false then
        if g_server ~= nil then
            g_server:broadcastEvent(MapZoomEvent.new(vehicle, zoom), nil, nil, vehicle)
        else
            g_client:getServerConnection():sendEvent(MapZoomEvent.new(vehicle, zoom))
        end
    end
end